@@ -153,6 +153,7 @@ sub on_start_element {
 sub on_start_block {
     my $self = shift;
     my $blk  = shift;
+
     #    warn "start element ". $blk->local_name;
     # call on_child for curretn element
     if ( my $elem = $self->current_element ) {
@@ -166,7 +167,8 @@ sub on_start_block {
 
 sub on_end_element {
     my $self = shift;
-#    warn ref($self)." on end element". $_[0]->local_name;
+
+    #    warn ref($self)." on end element". $_[0]->local_name;
     return $self->on_end_block(@_);
 }
 
@@ -262,6 +264,10 @@ sub run_para {
     my $self = shift;
     my @in   = $self->__expand_array_ref(@_);
     foreach my $el (@in) {
+        if ( UNIVERSAL::isa( $el, 'XML::ExtOn::Element' ) ) {
+            $self->_process_comm($el);
+            next;
+        }
         unless ( exists $el->{type} ) {
             $self->__process_events( $self->__make_events($el) );
         }
