@@ -1,4 +1,4 @@
-package Test::Filter;
+package Test::FilterDocBook;
 use strict;
 use warnings;
 use Test::More;
@@ -80,7 +80,7 @@ sub new {
         'Perl6::Pod::Parser::Doformatted',
         'Perl6::Pod::Parser::ListLevels',
         'Perl6::Pod::Parser::AddHeadLevels',
-        'Test::Filter', $self
+        'Test::FilterDocBook', $self
     );
 }
 
@@ -274,7 +274,7 @@ Zahatski Aliaksandr, <zag@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 by Zahatski Aliaksandr
+Copyright (C) 2009-2010 by Zahatski Aliaksandr
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
